@@ -81,6 +81,9 @@ def upload_nexus_raw():
     if response.status_code == 204:
         print("Nexus Upload successful")
         return __main__.sys.exit(0)
+    elif response.status_code == 404:
+        print("ERROR: Invalid Nexus URL specified. URL not found.")
+        return __main__.sys.exit(1)
     elif response.status_code == 400 and ("release" in __main__.repository_name or "staging" in __main__.repository_name):
         print("Nexus Upload failed. Please modify version number")
         return __main__.sys.exit(1)
